@@ -13,9 +13,9 @@ import atexit
 import pycurl
 import threading
 try:
-    from cookielib import Cookie
+    from cookielib import Cookie, CookieJar
 except ImportError:
-    from http.cookiejar import Cookie  #py3
+    from http.cookiejar import Cookie, CookieJar  #py3
 
 try:
     from urllib import urlencode
@@ -142,6 +142,17 @@ class TornadoHTTPClient(CurlAsyncHTTPClient):
         return self._cookie
 
 
+    @property
+    def cookiejar(self):
+        cookiejar = CookieJar()
+        for domain, items in self.cookie.items():
+            for path, names in items.items():
+                for name, cookie in names.items():
+                    cookiejar.set_cookie(cookie)
+
+        return cookiejar
+
+
     def start(self):
         IOLoop.instance().start()
 
